import { montserrat, sourceSansPro } from "@/helpers/fonts"
import './globals.css'
import { Metadata } from "next";
import NavBar from "@/components/layout/Navbar";
import Footer from "@/components/layout/Footer";
import MoveToTop from "@/components/MoveToTop";

export const metadata: Metadata = {
	metadataBase: new URL(process.env.NEXT_PUBLIC_APP_URL ?? ""),

	applicationName: "ReadyforWork Help Center",
	title: 'Help Center',
	description: "Learn in-demand digital skills to future-proof your career: digital marketing, UX/UI, data science, software engineering, financial analysis. Work on your business ideas.",

	openGraph: {
		title: 'Help Center - ReadyforWork Help Center | Learn in-demand digital skills',
		description: "Learn in-demand digital skills to future-proof your career: digital marketing, UX/UI, data science, software engineering, financial analysis. Work on your business ideas.",
		url: process.env.NEXT_PUBLIC_APP_URL,
		siteName: 'Help Center ReadyforWork | Learn in-demand digital skills',
		images: "https://res.cloudinary.com/sfan/image/upload/v1684836444/education-meta-image_jc7z8z.jpg",
		type: 'website',
	},
	twitter: {
		card: 'summary_large_image',
		title: 'Help Center - ReadyforWork Help Center | Learn in-demand digital skills',
		description: "Learn in-demand digital skills to future-proof your career: digital marketing, UX/UI, data science, software engineering, financial analysis. Work on your business ideas.",
		images: ['https://res.cloudinary.com/sfan/image/upload/v1684836444/education-meta-image_jc7z8z.jpg'],
	},
	alternates: {
		canonical: process.env.NEXT_PUBLIC_APP_URL,
	}
};


export default function RootLayout({
	children,
}: {
	children: React.ReactNode
}) {
	return (
		<html lang="en" className={`${sourceSansPro.variable} ${montserrat.variable}`}>
			<body className={" antialiased relative overflow-x-hidden bg-gradient-to-b from-rfw-dark via-rfw-light to-rfw-light text-rfw-dark"}>
				<NavBar />

				<div className="mt-4">
					{children}
				</div>
				<MoveToTop/>
				<Footer />
			</body>
		</html>
	)
}
